@@ -3,13 +3,20 @@
 package GENSample;
 
 use strict;
+use warnings;
 
 use Gantry qw{ -TemplateEngine=TT };
 
 use JSON;
+use Gantry::Utils::TablePerms;
 
 our @ISA = qw( Gantry );
 
+
+use Sample::Model;
+sub schema_base_class { return 'Sample::Model'; }
+use Gantry::Plugins::DBIxClassConn qw( get_schema );
+
 #-----------------------------------------------------------------
 # $self->namespace() or Sample->namespace()
 #-----------------------------------------------------------------
@@ -54,17 +61,19 @@ sub do_main {
         $real_location .= '/';
     }
 
+    my @header_options = (
+        {
+            text => 'Add',
+            link => $real_location . "add",
+            type => 'create',
+        },
+    );
+
     my $retval = {
         headings       => [
             'Name',
             'Phone',
         ],
-        header_options => [
-            {
-                text => 'Add',
-                link => $real_location . "add",
-            },
-        ],
     };
 
     my %param = $self->get_param_hash;
@@ -87,6 +96,31 @@ sub do_main {
         } if scalar( @searches ) > 0;
     }
 
+    my @row_options = (
+        {
+            text => 'Edit',
+            type => 'update',
+        },
+        {
+            text => 'Delete',
+            type => 'delete',
+        },
+    );
+
+    my $perm_obj = Gantry::Utils::TablePerms->new(
+        {
+            site           => $self,
+            real_location  => $real_location,
+            header_options => \@header_options,
+            row_options    => \@row_options,
+        }
+    );
+
+    $retval->{ header_options } = $perm_obj->real_header_options;
+
+    my $limit_to_user_id = $perm_obj->limit_to_user_id;
+    $search->{ user_id } = $limit_to_user_id if ( $limit_to_user_id );
+
     my $schema = $self->get_schema();
     my @rows   = $TBL1->get_listing(
         {
@@ -95,24 +129,20 @@ sub do_main {
         }
     );
 
+    ROW:
     foreach my $row ( @rows ) {
+        last ROW if $perm_obj->hide_all_data;
+
         my $id = $row->id;
+
         push(
             @{ $retval->{rows} }, {
+                orm_row => $row,
                 data => [
                     $row->name,
                     $row->phone,
                 ],
-                options => [
-                    {
-                        text => 'Edit',
-                        link => $real_location . "edit/$id",
-                    },
-                    {
-                        text => 'Delete',
-                        link => $real_location . "delete/$id",
-                    },
-                ],
+                options => $perm_obj->real_row_options( $row ),
             }
         );
     }
@@ -126,7 +156,7 @@ sub do_main {
             rows            => $retval->{ rows },
         };
 
-        my $json = objToJson( $obj );
+        my $json = objToJson( $obj, { skipinvalid => 1 } );
         return( $json );
     }
 
@@ -184,12 +214,16 @@ Sample should inherit from this module.
 
 =over 4
 
+=item namespace
+
 =item init
 
 =item do_main
 
 =item form
 
+=item schema_base_class
+
 
 =back
 
