@@ -3,9 +3,11 @@
 package Apps::Checkbook::GEN::PayeeOr;
 
 use strict;
+use warnings;
 
 use base 'Apps::Checkbook';
 use JSON;
+use Gantry::Utils::TablePerms;
 
 use Apps::Checkbook::Model::payee qw(
     $PAYEE
@@ -26,16 +28,18 @@ sub do_main {
         $real_location .= '/';
     }
 
+    my @header_options = (
+        {
+            text => 'Add',
+            link => $real_location . "add",
+            type => 'create',
+        },
+    );
+
     my $retval = {
         headings       => [
             'Name',
         ],
-        header_options => [
-            {
-                text => 'Add',
-                link => $real_location . "add",
-            },
-        ],
     };
 
     my %param = $self->get_param_hash;
@@ -58,25 +62,46 @@ sub do_main {
         } if scalar( @searches ) > 0;
     }
 
+    my @row_options = (
+        {
+            text => 'Edit',
+            type => 'update',
+        },
+        {
+            text => 'Delete',
+            type => 'delete',
+        },
+    );
+
+    my $perm_obj = Gantry::Utils::TablePerms->new(
+        {
+            site           => $self,
+            real_location  => $real_location,
+            header_options => \@header_options,
+            row_options    => \@row_options,
+        }
+    );
+
+    $retval->{ header_options } = $perm_obj->real_header_options;
+
+    my $limit_to_user_id = $perm_obj->limit_to_user_id;
+    $search->{ user_id } = $limit_to_user_id if ( $limit_to_user_id );
+
     my @rows = $PAYEE->get_listing();
 
+    ROW:
     foreach my $row ( @rows ) {
+        last ROW if $perm_obj->hide_all_data;
+
         my $id = $row->id;
+
         push(
             @{ $retval->{rows} }, {
+                orm_row => $row,
                 data => [
                     $row->name,
                 ],
-                options => [
-                    {
-                        text => 'Edit',
-                        link => $real_location . "edit/$id",
-                    },
-                    {
-                        text => 'Delete',
-                        link => $real_location . "delete/$id",
-                    },
-                ],
+                options => $perm_obj->real_row_options( $row ),
             }
         );
     }
@@ -90,7 +115,7 @@ sub do_main {
             rows            => $retval->{ rows },
         };
 
-        my $json = objToJson( $obj );
+        my $json = objToJson( $obj, { skipinvalid => 1 } );
         return( $json );
     }
 
